==> okteta_0.25.5.orig.tar.xz: okteta-0.25.5/libs/kasten/controllers/program/quit/quitcontroller.cpp <==
/*
    This file is part of the Kasten Framework, made within the KDE community.

    Copyright 2006-2008 Friedrich W. H. Kossebau <kossebau@kde.org>

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) version 3, or any
    later version accepted by the membership of KDE e.V. (or its
    successor approved by the membership of KDE e.V.), which shall
    act as a proxy defined in Section 6 of version 3 of the license.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library. If not, see <http://www.gnu.org/licenses/>.
*/

#include "quitcontroller.h"

// KF5
#include <KXmlGuiWindow>
#include <KActionCollection>
#include <KStandardAction>

namespace Kasten {

QuitController::QuitController(KProgram* program, KXmlGuiWindow* window)
    : mMainWindow(window)
{
    Q_UNUSED(program)

    auto* quitAction = KStandardAction::quit(this, &QuitController::quit, this);

    mMainWindow->actionCollection()->addAction(quitAction->objectName(), quitAction);
}

void QuitController::setTargetModel(AbstractModel* model)
{
    Q_UNUSED(model)
}

void QuitController::quit()
{
    mMainWindow->close();
//   Program->quit(); // TODO: think about a base program
}

}

==> okteta-0.26.1.tar.xz: okteta-0.26.1/libs/kasten/controllers/program/quit/quitcontroller.cpp <==
/*
    This file is part of the Kasten Framework, made within the KDE community.

    Copyright 2006-2008 Friedrich W. H. Kossebau <kossebau@kde.org>

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) version 3, or any
    later version accepted by the membership of KDE e.V. (or its
    successor approved by the membership of KDE e.V.), which shall
    act as a proxy defined in Section 6 of version 3 of the license.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library. If not, see <http://www.gnu.org/licenses/>.
*/

#include "quitcontroller.hpp"

// KF
#include <KXmlGuiWindow>
#include <KActionCollection>
#include <KStandardAction>

namespace Kasten {

QuitController::QuitController(KXmlGuiWindow* window)
    : mMainWindow(window)
{
    auto* quitAction = KStandardAction::quit(this, &QuitController::quit, this);

    mMainWindow->actionCollection()->addAction(quitAction->objectName(), quitAction);
}

void QuitController::setTargetModel(AbstractModel* model)
{
    Q_UNUSED(model)
}

void QuitController::quit()
{
    mMainWindow->close();
//   Program->quit(); // TODO: think about a base program
}

}
